@@ -1,4 +1,4 @@
-// $Id: issupportedstring.c 2449 2007-01-10 18:53:07Z dhozac $    --*- c -*--
+// $Id: issupportedstring.c 2589 2007-08-16 03:06:50Z dhozac $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -34,7 +34,7 @@ static struct {
   DECL(VKILL),   DECL(IATTR),     DECL(RLIMIT),   DECL(COMPAT),
   DECL(MIGRATE), DECL(NAMESPACE), DECL(SCHED),    DECL(VINFO),
   DECL(VHI),     DECL(VSHELPER0), DECL(VSHELPER), DECL(VWAIT),
-  DECL(VNET),    DECL(VSTAT),
+  DECL(VNET),    DECL(VSTAT),     DECL(PPTAG),
 };
 
 bool
