@@ -1,4 +1,4 @@
-// $Id: ncaps-net.c 2393 2006-11-23 18:30:29Z dhozac $    --*- c -*--
+// $Id: ncaps-net.c 2585 2007-08-12 00:13:31Z dhozac $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <ensc@delenn.intern.sigma-chemnitz.de>
 //  
@@ -31,8 +31,7 @@
 #define DECL(STR, VAL) { STR, sizeof(STR)-1, VAL }
 
 static struct Mapping_uint64 const VALUES[] = {
-#warning Add the 'ncap' values here
-  DECL("", 0)
+  DECL("raw_icmp", VC_NXC_RAW_ICMP),
 };
 
 inline static char const *
