@@ -1,4 +1,4 @@
-// $Id: syscall_netremove.c 2249 2006-01-18 23:40:15Z ensc $    --*- c -*--
+// $Id: syscall_netremove.c 2578 2007-08-08 20:05:26Z dhozac $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -20,23 +20,34 @@
 #  include <config.h>
 #endif
 
+#include <string.h>
+
 #include "vserver.h"
-#include "vserver-internal.h"
 #include "virtual.h"
 
+#if defined(VC_ENABLE_API_NET) && defined(VC_ENABLE_API_NETV2)
+#  define VC_MULTIVERSION_SYSCALL 1
+#endif
+#include "vserver-internal.h"
+
 #if defined(VC_ENABLE_API_NET)
 #  include "syscall_netremove-net.hc"
 #endif
 
-#if defined(VC_ENABLE_API_NET)
+#if defined(VC_ENABLE_API_NETV2)
+#  include "syscall_netremove-netv2.hc"
+#endif
+
+#if defined(VC_ENABLE_API_NET) || defined(VC_ENABLE_API_NETV2)
 int
-vc_net_remove(nid_t nid, struct vc_net_nx const *info)
+vc_net_remove(nid_t nid, struct vc_net_addr const *info)
 {
   if (info==0) {
     errno = EFAULT;
     return -1;
   }
   
-  CALL_VC(CALL_VC_NET(vc_net_remove, nid, info));
+  CALL_VC(CALL_VC_NETV2(vc_net_remove, nid, info),
+	  CALL_VC_NET  (vc_net_remove, nid, info));
 }
 #endif
